Tento text byl publikován jako součást knihy (Lopatková et al., 2016) vydané nakladatelstvím Karolinum.

#

Valenční slovník českých sloves (též VALLEX 3.0) poskytuje informace o valenční struktuře českých sloves v jejich jednotlivých významech, které charakterizuje pomocí glos a příkladů; tyto základní údaje jsou doplněny o některé další syntaktické a sémantické charakteristiky. VALLEX 3.0 zachycuje 4 586 českých sloves, která odpovídají 10 821 lexikálním jednotkám, tedy „danému slovesu v daném významu“.

VALLEX 3.0 navazuje na vydání slovníku z roku 2008 (Lopatková et al., 2008). Ačkoli se kvantitativně příliš neliší od předchozí verze 2.0, zásadně se proměnila jeho koncepce. Model slovníku byl uzpůsoben tak, aby umožňoval teoreticky adekvátně a přitom ekonomicky popisovat změny ve valenční struktuře českých sloves. Slovník nyní sestává ze dvou komponent: slovníková (datová) komponenta obsahuje lexikální hesla popisující valenční chování jednotlivých lexémů sloves, zatímco gramatická komponenta (představující část celkové gramatiky jazyka) obsahuje gramatická pravidla popisující možné změny v jejich valenční struktuře. Ve slovníku jsou reflektovány gramaticky podmíněné změny spojené s diatezemi, reciprocitou a reflexivitou. Slovník tak zachycuje nejen nepříznakové povrchověsyntaktické realizace lexikálních jednotek slovesných lexémů (aktivní, nereciproční a nereflexivní konstrukce), ale též struktury příznakové (pasivní, reciproční nebo reflexivní konstrukce). Z lexikálně motivovaných změn jsou zde vyznačeny ty změny, které jsou spojeny se změnou lexikální jednotky téhož slovesného lexému (např. typ naložit vůz senem – naložit seno na vůz). Dále jsou k lexikálním jednotkám VALLEXu doplněny příklady z Českého národního korpusu a z Pražského závislostního korpusu, slovník je též propojen se slovníkem PDT-Vallex.

## Poděkování

Za inspirativní poznámky, diskuse nad tématy souvisejícími s valencí sloves i lidskou podporu děkujeme především prof. Jarmile Panevové, autorce valenční teorie, ze které při popisu lexikálních hesel ve VALLEXu vycházíme. Naše díky náleží též dlouholeté spolupracovnici Karolíně Skwarské, stejně jako ostatním kolegům, rodinám a přátelům.

VALLEX je vytvářen od roku 2001 v Ústavu formální a aplikované lingvistiky na Matematicko-fyzikální fakultě Univerzity Karlovy. Podílel se na něm výzkumný tým ve složení Markéta Lopatková, Václava Kettnerová a Zdeněk Žabokrtský, doplněný o další spolupracovníky, Eduarda Bejčka a Annu Vernerovou. Děkujeme též našim spolupracovníkům, kteří se podíleli na přípravě starších verzí slovníku, a to Karolíně Skwarské, Kláře Hrstkové, Michaele Nové a Miroslavu Tichému. Dále děkujeme autorům nového webového rozhraní Jiřímu Balharovi a Benediktu Straňákovi.

Práce na slovníku VALLEX 3.0 a jeho vydání byly podpořeny projektem GAČR Lexikografické zpracování syntaktických a sémantických vlastností sloves v češtině, GA P406-12-0557. Doprovodný text byl publikován jako součást knihy (Lopatková et al., 2016) vydané nakladatelstvím Karolinum.

Při zpracovávání sloves ve slovníku VALLEX jsme využívali následující slovníky a korpusy českých textů:

- BRIEF (Pala – Ševeček, 1997);
- Slovník spisovné češtiny pro školu a veřejnost (Filipec et al., 2005, dále SSČ)
- Slovník spisovného jazyka českého (Havránek et al., 1964, dále SSJČ);
- Slovesa pro praxi (Svozilová et al., 1997);
- Český národní korpus, řadu SYN (Křen et al., 2016, dále SYN); web
- Pražský závislostní korpus (Bejček et al., 2013, dále PDT). web

Slovník dále využívá jazykových zdrojů zpracovaných a distribuovaných v rámci projektu MŠMT ČR LINDAT/CLARIN LM2015071.

## Zpřístupnění slovníku

VALLEX je budován jako odpověď na potřebu rozsáhlého a kvalitního veřejně dostupného slovníku, který by obsahoval syntaktické a sémantické charakteristiky českých sloves a byl přitom široce uplatnitelný v aplikacích pro zpracování přirozeného jazyka. Při navrhování koncepce slovníku byl proto kladen důraz na všestranné využití jak pro lidského uživatele, tak pro automatické zpracování češtiny.

VALLEX je proto zveřejněn ve třech formátech:

- VALLEX byl publikován jako tradiční tištěný slovník obsahující – mimo klasické slovníkové části – též teoretický úvod představující základní koncepční postupy uplatněné při budování slovníku, dále podrobný popis hesla; součástí publikace je též gramatická komponenta sestávající z bohatě exemplifikovaných formálních pravidel pro odvozování příznakových slovesných konstrukcí (Lopatková et al., 2016).
- VALLEX je dostupný jako webový slovník, který umožňuje rychlé a pohodlné vyhledávání podle řady předdefinovaných kritérií http://ufal.mff.cuni.cz/vallex/3.0/.
- VALLEX je distribuován ve formě strojově čitelného souboru (XML formát), který umožňuje komplexní dotazy nad slovníkovými hesly i využití slovníku v nástrojích pro automatické zpracování češtiny http://hdl.handle.net/11234/1-2307.

## Citování slovníku

Slovník VALLEX je veřejně dostupný slovník pod licencí Creative Commons 4.0 (CC BY-NC-SA). Jeho nekomerční využití je podmíněno přiměřenou citací alespoň jedné z následujících publikací (případně dalších relevantních publikací, viz odkaz níže):

- Lopatková et al. (2016)
  Lopatková, M. – Kettnerová, V. – Bejček, E. – Vernerová, A. – Žabokrtský, Z. (2016): Valenční slovník českých sloves VALLEX. Nakladatelství Karolinum, Praha, 698 pp.

      @book{2016-vallex-book,
      	title = {Valen{\v{c}}n{\'{i}} slovn{\'{i}}k {\v{c}}esk{\'{y}}ch sloves {VALLEX}},
      	author = {Mark{\'{e}}ta Lopatkov{\'{a}} and V{\'{a}}clava Kettnerov{\'{a}}
      		and Eduard Bej{\v{c}}ek and Anna Vernerov{\'{a}}
      		and Zden{\v{e}}k {\v{Z}}abokrtsk{\'{y}}},
      	year = {2016},
      	publisher = {Karolinum},
      	address = {Praha},
      	isbn = {978-80-246-3542-2},
      }

- Kettnerová et al. (2012)
  Kettnerová, V. – Lopatková, M. – Bejček, E. (2012): The Syntax-Semantics Interface of Czech Verbs in the Valency Lexicon. In Proceedings of the 15th EURALEX International Congress. Department of Linguistics and Scandinavian Studies, University of Oslo, Oslo, Norway, pp. 434-443. (PDF)

      @inproceedings{12-EURALEX-sep,
      	booktitle = {Proceedings of the 15th {EURALEX} International Congress},
      	editor = {Ruth Fjeld and Julie Torjusen},
      	title = {The Syntax-Semantics Interface of Czech Verbs in the Valency Lexicon},
      	author = {V{\'{a}}clava Kettnerov{\'{a}} and Mark{\'{e}}ta Lopatkov{\'{a}}
      		and Eduard Bej{\v{c}}ek},
      	year = {2012},
      	publisher = {Department of Linguistics and Scandinavian Studies, University of Oslo},
      	address = {Oslo},
      	pages = {434--443},
      }

Spolu s výše uvedenými je možné citovat také samotné data VALLEXu 3.0 přístupná na LINDATu:

- Lopatková et al. (2016b)
  Lopatková, M. – Kettnerová, V. – Bejček, E. – Vernerová, A. – Žabokrtský, Z. (2016): VALLEX 3.0. LINDAT/CLARIN digital library at the Institute of Formal and Applied Linguistics, Charles University, http://hdl.handle.net/11234/1-2307.

      @misc{vallex30-data,
      	title = {{VALLEX} 3.0},
      	author = {Mark{\'e}ta Lopatkov{\'a} and V{\'a}clava Kettnerov{\'a}
      		and Eduard Bej{\v c}ek and Anna Vernerov{\'a}
      		and Zden{\v e}k {\v Z}abokrtsk{\'y}},
      	url = {http://hdl.handle.net/11234/1-2307},
      	note = {{LINDAT}/{CLARIN} digital library at the Institute
      		of Formal and Applied Linguistics, Charles University},
      	copyright = {Creative Commons - Attribution-{NonCommercial}-{ShareAlike} 4.0
      		International ({CC} {BY}-{NC}-{SA} 4.0)},
      	year = {2016},
      }

## Odborné publikace vztahující se k VALLEXu

Postupné budování VALLEXu je popsáno v řadě odborných publikacích, jejich seznam lze nalézt na webové stránce projektu.

### Seznam literatury

- Bejček et al. (2013)
  Bejček, E. et al. (2013): Prague Dependency Treebank 3.0.: Prague, Czech republic, Univerzita Karlova v Praze, MFF, ÚFAL. (Dostupné z http://ufal.mff.cuni.cz/pdt3.0.)
- Filipec et al. (2005)
  Filipec, J. et al. (ed.) (2005): Slovník spisovné češtiny pro školu a veřejnost. Praha, Academia. (Co-editors: Daneš, F. – Machač, J. – Mejstřík, V.)
- Havránek et al. (1964)
  Havránek, B. et al. (ed.) (1964): Slovník spisovného jazyka českého. Praha, Academia. (Co-editors: Bělič, J. – Helcl, M. – Jedlička, A. et al.)
- Křen et al. (2016)
  Křen, M. et al. (2016): Český národní korpus. Praha, Ústav Českého národního korpusu FF UK. (Dostupné z http://www.korpus.cz.)
- Lopatková et al. (2016)
  Lopatková, M. – Kettnerová, V. – Bejček, E. – Vernerová, A. – Žabokrtský, Z. (2016): Valenční slovník českých sloves VALLEX. Nakladatelství Karolinum, Praha, 698 pp.
- Lopatková et al. (2008)
  Lopatková, M. – Žabokrtský, Z. – Kettnerová, V. (2008): Valenční slovník českých sloves. Nakladatelství Karolinum, Praha, 382 pp.
- Pala – Ševeček (1997)
  Pala, K. – Ševeček, P. (1997): Valence českých sloves. In Sborník prací Filozofické fakulty brněnské univerzity, 46 / Řada jazykovědná, s. 41–54, Brno, Masarykova Univerzita Brno.
- Svozilová et al. (1997)
  Svozilová, N. – Prouzová, H. – Jirsová, A. (1997): Slovesa pro praxi. Valenční slovník nejčastějších českých sloves. Praha, Academia.